@@ -54,7 +54,7 @@
 #endif
 #endif
 
-#define VERSION_STRING	"0.3"
+#define VERSION_STRING	"0.4unreleased"
 
 enum option_id_t {
 	OPT_LABEL,
@@ -249,9 +249,12 @@ connect_inet(const int socktype, struct option_t * const options __unused,
 		    socktype == SOCK_STREAM ? "tcp" : "udp");
 	const int optval = 1;
 	if (setsockopt(sock, SOL_SOCKET, SO_REUSEADDR,
-	    &optval, sizeof(optval)) == -1 ||
-	    setsockopt(sock, SOL_SOCKET, SO_REUSEPORT,
-	    &optval, sizeof(optval)) == -1)
+		       &optval, sizeof(optval)) == -1
+#ifndef __gnu_hurd__
+	    || setsockopt(sock, SOL_SOCKET, SO_REUSEPORT,
+			  &optval, sizeof(optval)) == -1
+#endif
+	    )
 		err(EXIT_FAILURE, "Could not set the socket options for %s:%s",
 		    addrstr, portstr);
 	if (bind(sock, res->ai_addr, res->ai_addrlen) == -1)
